## Notebooks

Jupyter Notebooks with Analysis of bio-geographic changes in species environments.

Name | Description
-----|------------
`106656-co-occurrence-preliminary-analysis.ipynb`|Preliminary analysis of occcurrences with `taxonid` 106656
`106656-depth-function-analysis.ipynb`|Analysing depth of `taxonid` 106656 as a function of SST and Salinity
`analysing_species_depth_using_obis.ipynb`|Initial time series analysis of depth for various species (exploratory data analysis)
`data_collection.ipynb`| Collecting data about species from OBIS (Ocean Biogeographic Information System)
`euphausiidae_dana_depth_analysis.ipynb`|Analysing depth of species *Euphausiidae Dana* as a function of SST and Salinity

Jump into each notebook individually to see the analysis and infer the conclusion.